==> haskell-data-dword-0.3.2-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-dword
version:              0.3.2
visibility:           public
id:                   data-dword-0.3.2-CCJj4dAqc1QB6jQv7zCp2a
key:                  data-dword-0.3.2-CCJj4dAqc1QB6jQv7zCp2a
license:              BSD-3-Clause
copyright:            2011-2019 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-dword
synopsis:             Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.

category:             Data
abi:                  327a89b41dbd38337490f7c2011c722b
exposed:              True
exposed-modules:      Data.DoubleWord Data.DoubleWord.TH
hidden-modules:       Data.DoubleWord.Base
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-dword-0.3.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-dword-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-dword-0.3.2
hs-libraries:         HSdata-dword-0.3.2-CCJj4dAqc1QB6jQv7zCp2a
depends:
    base-4.15.0.0 data-bword-0.1.0.1-dMe7RI0E6sFWIXJGrJrOf
    ghc-prim-0.7.0 hashable-1.3.3.0-3L81lU2ygSqqBRC8gEHN5
    template-haskell-2.17.0.0

haddock-interfaces:   /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html:         /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-dword-0.3.2-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-dword
version:              0.3.2
visibility:           public
id:                   data-dword-0.3.2-3Lxsl0nIgqDD29NP2IliKS
key:                  data-dword-0.3.2-3Lxsl0nIgqDD29NP2IliKS
license:              BSD-3-Clause
copyright:            2011-2019 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-dword
synopsis:             Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.

category:             Data
abi:                  d336ed35c90a789a6bf7fa1923c663c8
exposed:              True
exposed-modules:      Data.DoubleWord Data.DoubleWord.TH
hidden-modules:       Data.DoubleWord.Base
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-dword-0.3.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-dword-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-dword-0.3.2
hs-libraries:         HSdata-dword-0.3.2-3Lxsl0nIgqDD29NP2IliKS
depends:
    base-4.15.0.0 data-bword-0.1.0.1-dMe7RI0E6sFWIXJGrJrOf
    ghc-prim-0.7.0 hashable-1.3.4.0-6dnecuFViZBGFpHQwXe7GH
    template-haskell-2.17.0.0

haddock-interfaces:   /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html:         /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
